# Generated by Django 2.2 on 2019-05-28 02:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0006_auto_20190528_0258'),
        ('engines', '0052_cluster_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='scale',
            name='stack',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.PROTECT, to='engines.Stack'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='stack',
            name='engines',
            field=models.ManyToManyField(to='engines.Engine'),
        ),
        migrations.AlterField(
            model_name='engine',
            name='name',
            field=models.CharField(max_length=50, unique=True),
        ),
        migrations.AlterUniqueTogether(
            name='engine',
            unique_together=set(),
        ),
        migrations.RemoveField(
            model_name='engine',
            name='components',
        ),
        migrations.RemoveField(
            model_name='engine',
            name='stack',
        ),
        migrations.DeleteModel(
            name='Component',
        ),
    ]
