# Generated by Django 2.1.7 on 2019-04-14 07:31

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0031_auto_20190413_1111'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cluster',
            name='current_step',
        ),
        migrations.RemoveField(
            model_name='cluster',
            name='instances',
        ),
        migrations.RemoveField(
            model_name='cluster',
            name='remedy_script_todo',
        ),
        migrations.RemoveField(
            model_name='cluster',
            name='step_instances',
        ),
        migrations.RemoveField(
            model_name='step',
            name='created_time',
        ),
        migrations.RemoveField(
            model_name='step',
            name='remedy_script_todo',
        ),
        migrations.AddField(
            model_name='step',
            name='status',
            field=models.PositiveIntegerField(choices=[(0, 'null'), (1, 'active'), (2, 'block'), (3, 'suspend'), (4, 'shutdown'), (5, 'poweroff'), (6, 'breakdown'), (7, 'pause'), (8, 'failure'), (9, 'host_lost'), (10, 'instance_lost'), (11, 'building')], default=11, editable=False),
        ),
        migrations.AddField(
            model_name='step',
            name='uuid',
            field=models.UUIDField(auto_created=True, default=uuid.uuid4, editable=False),
        ),
    ]
