# Generated by Django 2.2 on 2019-04-28 22:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0038_auto_20190427_0841'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cloud',
            name='_driver',
            field=models.CharField(choices=[('clouds.drivers.evcloud', 'clouds.drivers.evcloud'), ('clouds.drivers.openstack', 'clouds.drivers.openstack')], max_length=50),
        ),
    ]
