# Generated by Django 2.2 on 2019-05-27 21:35

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('engines', '0052_cluster_active'),
        ('data', '0004_auto_20190527_2123'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='dataset',
            name='uri',
        ),
        migrations.AlterUniqueTogether(
            name='datainstance',
            unique_together={('engine', 'name'), ('name', 'cluster', 'owner')},
        ),
        migrations.RemoveField(
            model_name='datainstance',
            name='uri_suffix',
        ),
    ]
