# Generated by Django 2.1.7 on 2019-04-05 03:29

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0003_auto_20190403_0352'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='scale',
            name='remedy_script',
        ),
        migrations.AddField(
            model_name='component',
            name='_remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
        migrations.AddField(
            model_name='component',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='engine',
            name='_remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
        migrations.AddField(
            model_name='engine',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='scale',
            name='_remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
        migrations.AddField(
            model_name='scale',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='component',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='engine',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='scale',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterUniqueTogether(
            name='component',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='engine',
            unique_together=set(),
        ),
    ]
