# Generated by Django 2.1.7 on 2019-04-15 05:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0027_remove_group_blueprint'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='hosts',
            field=models.TextField(blank=True, default='', max_length=51200),
        ),
    ]
