# Generated by Django 2.1.7 on 2019-04-11 23:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0020_clusteroperation_serial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='clusteroperation',
            name='auto',
        ),
        migrations.AddField(
            model_name='clusteroperation',
            name='manual',
            field=models.BooleanField(default=True),
        ),
    ]
