# Generated by Django 2.2 on 2019-05-28 02:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0005_auto_20190527_2135'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='dataengine',
            name='component',
        ),
        migrations.RemoveField(
            model_name='dataengine',
            name='endpoint',
        ),
    ]
