# Generated by Django 2.1.7 on 2019-04-13 07:48

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0024_auto_20190413_0608'),
    ]

    operations = [
        migrations.AddField(
            model_name='step',
            name='uuid',
            field=models.UUIDField(auto_created=True, default=uuid.uuid4, editable=False),
        ),
    ]
