# Generated by Django 2.2 on 2019-04-28 04:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0047_auto_20190428_0356'),
    ]

    operations = [
        migrations.AddField(
            model_name='engine',
            name='description',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
    ]
