# Generated by Django 2.1.7 on 2019-04-12 06:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0018_auto_20190411_2340'),
    ]

    operations = [
        migrations.AlterField(
            model_name='instanceoperation',
            name='manual',
            field=models.BooleanField(default=True, editable=False),
        ),
    ]
