# Generated by Django 2.1.7 on 2019-04-11 05:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0015_instanceoperation_tidied'),
        ('engines', '0017_auto_20190411_0312'),
    ]

    operations = [
        migrations.AddField(
            model_name='clusteroperation',
            name='instances',
            field=models.ManyToManyField(editable=False, to='clouds.Instance'),
        ),
    ]
