# Generated by Django 2.2 on 2019-04-28 03:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0046_auto_20190428_0338'),
    ]

    operations = [
        migrations.AddField(
            model_name='component',
            name='stack',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.PROTECT, to='engines.Stack'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='engine',
            name='stack',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.PROTECT, to='engines.Stack'),
            preserve_default=False,
        ),
    ]
