# Generated by Django 2.1.7 on 2019-04-06 09:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('user', '0002_auto_20190405_0253'),
        ('clouds', '0012_auto_20190406_0938'),
    ]

    operations = [
	migrations.AlterField(
            model_name='balance',
            name='location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='clouds.Cloud'),
        ),
    ]
