# Generated by Django 2.1.7 on 2019-04-17 03:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0030_auto_20190417_0157'),
        ('engines', '0036_auto_20190417_0157'),
    ]

    operations = [
        migrations.CreateModel(
            name='ClusterGroupOperation',
            fields=[
            ],
            options={
                'proxy': True,
                'indexes': [],
            },
            bases=('clouds.groupoperation',),
        ),
    ]
