# Generated by Django 2.1.7 on 2019-04-15 04:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0026_auto_20190415_0228'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='group',
            name='blueprint',
        ),
    ]
