# Generated by Django 2.2 on 2019-04-18 07:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0031_group_hosts'),
    ]

    operations = [
        migrations.AlterField(
            model_name='group',
            name='hosts',
            field=models.TextField(blank=True, default='', editable=False, max_length=5120),
        ),
        migrations.AlterField(
            model_name='groupoperation',
            name='script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
        migrations.AlterField(
            model_name='instanceoperation',
            name='script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
    ]
