# Generated by Django 2.1.7 on 2019-04-03 03:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0005_auto_20190402_2147'),
        ('engines', '0002_auto_20190402_2147'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='scaleblueprint',
            unique_together=set(),
        ),
        migrations.RemoveField(
            model_name='scaleblueprint',
            name='instance_blueprints',
        ),
        migrations.RemoveField(
            model_name='scaleblueprint',
            name='owner',
        ),
        migrations.RemoveField(
            model_name='scale',
            name='init_blueprint',
        ),
        migrations.RemoveField(
            model_name='scale',
            name='step_blueprint',
        ),
        migrations.AddField(
            model_name='scale',
            name='init_blueprints',
            field=models.ManyToManyField(related_name='initialized_scales', to='clouds.InstanceBlueprint'),
        ),
        migrations.AddField(
            model_name='scale',
            name='step_blueprints',
            field=models.ManyToManyField(related_name='steped_scales', to='clouds.InstanceBlueprint'),
        ),
        migrations.DeleteModel(
            name='ScaleBlueprint',
        ),
    ]
