# Generated by Django 2.2 on 2019-04-28 03:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0045_stack'),
    ]

    operations = [
        migrations.AlterField(
            model_name='component',
            name='endpoint',
            field=models.CharField(blank=True, default='', max_length=200),
        ),
    ]
