# Generated by Django 2.1.7 on 2019-04-02 21:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0004_auto_20190402_0217'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='instancetemplate',
            options={'verbose_name': 'template'},
        ),
        migrations.RemoveField(
            model_name='mount',
            name='built_time',
        ),
    ]
