# Generated by Django 2.1.7 on 2019-04-14 07:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0022_auto_20190413_1111'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='instance',
            name='remedy_script_todo',
        ),
    ]
