# Generated by Django 2.2 on 2019-04-27 08:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0037_auto_20190426_1924'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='image',
            unique_together={('cloud', 'name')},
        ),
    ]
