# Generated by Django 2.1.7 on 2019-04-04 01:18

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('clouds', '0006_auto_20190403_2003'),
    ]

    operations = [
        migrations.RenameField(
            model_name='instanceblueprint',
            old_name='remedy_script',
            new_name='_remedy_script',
        ),
        migrations.RenameField(
            model_name='instancetemplate',
            old_name='remedy_script',
            new_name='_remedy_script',
        ),
        migrations.RemoveField(
            model_name='image',
            name='uuid',
        ),
        migrations.RemoveField(
            model_name='location',
            name='uuid',
        ),
        migrations.AddField(
            model_name='instanceblueprint',
            name='name',
            field=models.CharField(default='0', max_length=50),
        ),
        migrations.AddField(
            model_name='instancetemplate',
            name='owner',
            field=models.ForeignKey(default=1, editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='instancetemplate',
            name='public',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='location',
            name='_remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
        migrations.AlterField(
            model_name='image',
            name='access_id',
            field=models.CharField(max_length=50, verbose_name='actual id on the location'),
        ),
        migrations.AlterField(
            model_name='image',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='instance',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='instance',
            name='remark',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='instance',
            name='remedy_script_todo',
            field=models.TextField(blank=True, default='', max_length=51200),
        ),
        migrations.AlterField(
            model_name='instance',
            name='uuid',
            field=models.UUIDField(editable=False, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='instanceblueprint',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='instancetemplate',
            name='access_id',
            field=models.CharField(max_length=50, verbose_name='actual id on the location'),
        ),
        migrations.AlterField(
            model_name='location',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='volume',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='volume',
            name='remark',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='volume',
            name='uuid',
            field=models.UUIDField(editable=False, null=True, unique=True),
        ),
        migrations.AlterUniqueTogether(
            name='instancetemplate',
            unique_together=set(),
        ),
        migrations.RemoveField(
            model_name='instancetemplate',
            name='uuid',
        ),
    ]
