# Generated by Django 2.2 on 2019-04-26 19:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0036_group_destroy_script_todo'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='image',
            unique_together=set(),
        ),
    ]
