# Generated by Django 2.1.7 on 2019-04-15 01:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0025_auto_20190415_0119'),
        ('engines', '0034_auto_20190414_2200'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='step',
            name='cluster',
        ),
        migrations.RemoveField(
            model_name='step',
            name='instances',
        ),
        migrations.RemoveField(
            model_name='step',
            name='owner',
        ),
        migrations.RemoveField(
            model_name='stepoperation',
            name='serial',
        ),
        migrations.RemoveField(
            model_name='stepoperation',
            name='target',
        ),
        migrations.AddField(
            model_name='cluster',
            name='steps',
            field=models.ManyToManyField(blank=True, editable=False, to='clouds.Group'),
        ),
        migrations.AlterField(
            model_name='cluster',
            name='built_time',
            field=models.DateTimeField(blank=True, editable=False, null=True),
        ),
        migrations.DeleteModel(
            name='Step',
        ),
        migrations.DeleteModel(
            name='StepOperation',
        ),
    ]
