# Generated by Django 2.1.7 on 2019-04-14 07:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0032_auto_20190414_0731'),
    ]

    operations = [
        migrations.AddField(
            model_name='cluster',
            name='remedy_script_todo',
            field=models.TextField(blank=True, default='', max_length=51200),
        ),
        migrations.AddField(
            model_name='step',
            name='remedy_script_todo',
            field=models.TextField(blank=True, default='', max_length=51200),
        ),
    ]
