# Generated by Django 2.1.7 on 2019-04-13 07:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0026_auto_20190413_0750'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='clusteroperation',
            name='steps',
        ),
        migrations.AddField(
            model_name='clusteroperation',
            name='step',
            field=models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to='engines.Step'),
        ),
    ]
