# Generated by Django 2.1.7 on 2019-04-13 07:50

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0025_step_uuid'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='step',
            name='uuid',
        ),
        migrations.AddField(
            model_name='step',
            name='built_time',
            field=models.DateTimeField(blank=True, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='step',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
