# Generated by Django 2.1.7 on 2019-04-12 09:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0022_auto_20190412_0637'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='clusteroperation',
            name='broadcast',
        ),
    ]
