# Generated by Django 2.1.7 on 2019-04-04 23:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0010_auto_20190404_2346'),
    ]

    operations = [
        migrations.AlterField(
            model_name='volume',
            name='status',
            field=models.PositiveIntegerField(choices=[(0, 'null'), (1, 'available'), (2, 'mounted'), (3, 'building')], default=3, editable=False),
        ),
    ]
