# Generated by Django 2.2 on 2019-04-28 22:31

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('engines', '0048_engine_description'),
    ]

    operations = [
        migrations.AlterField(
            model_name='component',
            name='name',
            field=models.CharField(max_length=50),
        ),
        migrations.AlterField(
            model_name='engine',
            name='name',
            field=models.CharField(max_length=50),
        ),
        migrations.AlterField(
            model_name='stack',
            name='_driver',
            field=models.CharField(choices=[('engines.drivers.ambari', 'engines.drivers.ambari')], max_length=50),
        ),
        migrations.AlterUniqueTogether(
            name='component',
            unique_together={('stack', 'name')},
        ),
        migrations.AlterUniqueTogether(
            name='engine',
            unique_together={('stack', 'name')},
        ),
        migrations.AlterUniqueTogether(
            name='stack',
            unique_together={('owner', 'name')},
        ),
    ]
