# Generated by Django 2.1.7 on 2019-04-17 01:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0029_remove_group_hosts'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='groupoperation',
            options={'verbose_name': 'group operation'},
        ),
    ]
