# Generated by Django 2.1.7 on 2019-03-30 23:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0002_auto_20190330_2129'),
    ]

    operations = [
        migrations.AddField(
            model_name='instanceoperation',
            name='started_time',
            field=models.DateTimeField(blank=True, editable=False, null=True),
        ),
    ]
