# Generated by Django 2.1.7 on 2019-04-13 08:33

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0027_auto_20190413_0756'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='step',
            options={'ordering': ['pk']},
        ),
        migrations.RemoveField(
            model_name='cluster',
            name='steps',
        ),
        migrations.AddField(
            model_name='step',
            name='cluster',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='steps', to='engines.Cluster'),
        ),
    ]
