# Generated by Django 2.2 on 2019-04-17 06:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0030_auto_20190417_0157'),
        ('engines', '0038_auto_20190417_0526'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='stepoperation',
            name='serial',
        ),
        migrations.RemoveField(
            model_name='stepoperation',
            name='target',
        ),
        migrations.DeleteModel(
            name='Step',
        ),
        migrations.AlterField(
            model_name='cluster',
            name='steps',
            field=models.ManyToManyField(blank=True, editable=False, to='clouds.Group'),
        ),
        migrations.DeleteModel(
            name='StepOperation',
        ),
        migrations.CreateModel(
            name='StepOperation',
            fields=[
            ],
            options={
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('clouds.groupoperation',),
        ),
    ]
