# Generated by Django 2.1.7 on 2019-04-06 09:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0013_auto_20190406_0952'),
        ('user', '0003_auto_20190406_0938'),
    ]

    operations = [
        migrations.RenameField(
            model_name='balance',
            old_name='location',
            new_name='cloud',
        ),
        migrations.AlterUniqueTogether(
            name='balance',
            unique_together={('profile', 'cloud')},
        ),
    ]
