# Generated by Django 2.1.7 on 2019-04-13 08:36

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0028_auto_20190413_0833'),
    ]

    operations = [
        migrations.AlterField(
            model_name='step',
            name='cluster',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='steps', to='engines.Cluster'),
        ),
    ]
