# Generated by Django 2.2 on 2019-04-26 18:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0035_auto_20190420_0247'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='destroy_script_todo',
            field=models.TextField(blank=True, default='', max_length=51200),
        ),
    ]
