# Generated by Django 2.2 on 2019-06-25 20:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0013_auto_20190617_0430'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datainstance',
            name='status',
            field=models.PositiveIntegerField(choices=[(0, 'loading'), (1, 'running'), (2, 'stop')], default=0, editable=False),
        ),
    ]
