# Generated by Django 2.2 on 2019-06-14 20:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0008_dataset_uri'),
    ]

    operations = [
        migrations.AddField(
            model_name='dataengine',
            name='uri_prefix',
            field=models.CharField(default='test', max_length=2000),
            preserve_default=False,
        ),
    ]
