# Generated by Django 2.2 on 2019-04-20 02:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0032_auto_20190418_0732'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='instanceoperation',
            options={'ordering': ['-started_time', '-pk'], 'verbose_name': 'operation'},
        ),
    ]
