# Generated by Django 2.1.7 on 2019-04-10 22:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0014_auto_20190410_2050'),
    ]

    operations = [
        migrations.RenameField(
            model_name='clusteroperation',
            old_name='uuid',
            new_name='batch_uuid',
        ),
        migrations.AddField(
            model_name='clusteroperation',
            name='tidied',
            field=models.BooleanField(default=False, editable=False),
        ),
    ]
