# Generated by Django 2.2 on 2019-04-07 23:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0010_auto_20190406_2245'),
    ]

    operations = [
        migrations.AddField(
            model_name='cluster',
            name='deleting',
            field=models.BooleanField(default=False, editable=False),
        ),
    ]
