# Generated by Django 2.2 on 2019-06-14 20:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0009_dataengine_uri_prefix'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dataengine',
            name='uri_prefix',
            field=models.CharField(blank=True, default='', max_length=2000),
        ),
    ]
