# Generated by Django 2.1.7 on 2019-04-11 11:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0016_instanceoperation_auto'),
    ]

    operations = [
        migrations.AddField(
            model_name='instanceoperation',
            name='serial',
            field=models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to='clouds.InstanceOperation'),
        ),
    ]
