# Generated by Django 2.1.7 on 2019-04-15 02:28

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0025_auto_20190415_0119'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='blueprint',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.PROTECT, to='clouds.InstanceBlueprint'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='instanceoperation',
            name='target',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='clouds.Instance'),
            preserve_default=False,
        ),
    ]
