# Generated by Django 2.2 on 2019-04-18 07:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0040_auto_20190417_0719'),
    ]

    operations = [
        migrations.AddField(
            model_name='scale',
            name='_remedy_script_scale_in',
            field=models.TextField(blank=True, default='', max_length=5120, verbose_name='scale-in remedy script'),
        ),
        migrations.AlterField(
            model_name='clusteroperation',
            name='script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
        migrations.AlterField(
            model_name='scale',
            name='_remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120, verbose_name='scale-out remedy script'),
        ),
    ]
