# Generated by Django 2.1.7 on 2019-04-13 00:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0020_auto_20190413_0054'),
    ]

    operations = [
        migrations.AlterField(
            model_name='instanceoperation',
            name='log',
            field=models.TextField(editable=False, max_length=51200, null=True),
        ),
    ]
