# Generated by Django 2.1.7 on 2019-03-30 21:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='image',
            name='_remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
        migrations.AlterField(
            model_name='instance',
            name='remedy_script_todo',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
        migrations.AlterField(
            model_name='instanceblueprint',
            name='remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
    ]
