# Generated by Django 2.1.7 on 2019-04-06 09:52

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0012_auto_20190406_0938'),
    ]

    operations = [
        migrations.RenameField(
            model_name='image',
            old_name='location',
            new_name='cloud',
        ),
        migrations.RenameField(
            model_name='instance',
            old_name='location',
            new_name='cloud',
        ),
        migrations.RenameField(
            model_name='instanceblueprint',
            old_name='location',
            new_name='cloud',
        ),
        migrations.RenameField(
            model_name='instancetemplate',
            old_name='location',
            new_name='cloud',
        ),
        migrations.RenameField(
            model_name='volume',
            old_name='location',
            new_name='cloud',
        ),
        migrations.AlterField(
            model_name='cloud',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL, verbose_name='admin'),
        ),
        migrations.AlterField(
            model_name='image',
            name='access_id',
            field=models.CharField(max_length=50, verbose_name='actual id on the cloud'),
        ),
        migrations.AlterField(
            model_name='instancetemplate',
            name='access_id',
            field=models.CharField(max_length=50, verbose_name='actual id on the cloud'),
        ),
        migrations.AlterUniqueTogether(
            name='image',
            unique_together={('cloud', 'name')},
        ),
        migrations.AlterUniqueTogether(
            name='instanceblueprint',
            unique_together={('cloud', 'name')},
        ),
        migrations.AlterUniqueTogether(
            name='instancetemplate',
            unique_together={('cloud', 'name')},
        ),
    ]
