# Generated by Django 2.1.7 on 2019-04-02 21:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='clusteroperation',
            options={'verbose_name': 'operation'},
        ),
    ]
