# Generated by Django 2.1.7 on 2019-04-13 06:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0021_auto_20190413_0055'),
        ('engines', '0023_remove_clusteroperation_broadcast'),
    ]

    operations = [
        migrations.CreateModel(
            name='Step',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('remedy_script_todo', models.TextField(blank=True, default='', max_length=5120)),
                ('instances', models.ManyToManyField(blank=True, editable=False, to='clouds.Instance')),
            ],
        ),
        migrations.AddField(
            model_name='cluster',
            name='steps',
            field=models.ManyToManyField(blank=True, editable=False, to='engines.Step'),
        ),
        migrations.AddField(
            model_name='clusteroperation',
            name='steps',
            field=models.ManyToManyField(blank=True, editable=False, to='engines.Step'),
        ),
    ]
