# Generated by Django 2.1.7 on 2019-04-11 11:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0019_auto_20190411_0825'),
    ]

    operations = [
        migrations.AddField(
            model_name='clusteroperation',
            name='serial',
            field=models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to='engines.ClusterOperation'),
        ),
    ]
