# Generated by Django 2.2 on 2019-05-30 20:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0006_auto_20190528_0258'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datainstance',
            name='cluster',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='engines.Cluster'),
        ),
    ]
