# Generated by Django 2.2 on 2019-05-28 04:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0054_remove_scale_stack'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cluster',
            name='active',
        ),
    ]
