# Generated by Django 2.1.7 on 2019-04-11 03:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0015_instanceoperation_tidied'),
        ('engines', '0016_cluster_stepping_instances'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cluster',
            name='stepping_instances',
        ),
        migrations.AddField(
            model_name='cluster',
            name='step_instances',
            field=models.ManyToManyField(blank=True, editable=False, related_name='stepped_clusters', to='clouds.Instance'),
        ),
    ]
