# Generated by Django 2.1.7 on 2019-04-11 08:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0015_instanceoperation_tidied'),
    ]

    operations = [
        migrations.AddField(
            model_name='instanceoperation',
            name='auto',
            field=models.BooleanField(default=True, verbose_name='auto run'),
        ),
    ]
