# Generated by Django 2.2 on 2019-04-26 02:36

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='datainstance',
            name='public',
        ),
        migrations.AlterField(
            model_name='datainstance',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='datainstance',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='datainstance',
            name='remedy_script_todo',
            field=models.TextField(blank=True, default='', max_length=51200),
        ),
    ]
