# Generated by Django 2.1.7 on 2019-04-06 22:10

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0007_auto_20190406_2130'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cluster',
            name='scale',
        ),
        migrations.AlterField(
            model_name='cluster',
            name='current_step',
            field=models.PositiveIntegerField(default=0, editable=False, validators=[django.core.validators.MinValueValidator(0)]),
        ),
    ]
