# Generated by Django 2.2 on 2019-04-28 00:21

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0038_auto_20190427_0841'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('engines', '0044_auto_20190424_2135'),
    ]

    operations = [
        migrations.CreateModel(
            name='Stack',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50, unique=True)),
                ('_remedy_script', models.TextField(blank=True, default='', max_length=5120)),
                ('public', models.BooleanField(default=False)),
                ('enabled', models.BooleanField(default=True)),
                ('modified_time', models.DateTimeField(auto_now=True)),
                ('created_time', models.DateTimeField(auto_now_add=True)),
                ('remark', models.CharField(blank=True, max_length=100, null=True)),
                ('_driver', models.CharField(max_length=50)),
                ('host', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='clouds.Instance')),
                ('owner', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
