# Generated by Django 2.1.7 on 2019-04-06 21:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0006_auto_20190406_2130'),
    ]

    operations = [
        migrations.AlterField(
            model_name='scale',
            name='step_blueprints',
            field=models.ManyToManyField(blank=True, related_name='stepped_scales', to='clouds.InstanceBlueprint'),
        ),
    ]
