# Generated by Django 2.1.7 on 2019-04-06 09:38

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ('clouds', '0011_auto_20190404_2347'),
    ]

    operations = [
	migrations.RenameModel('Location', 'Cloud'),
        migrations.AlterField(
            model_name='image',
            name='location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='clouds.Cloud'),
        ),
        migrations.AlterField(
            model_name='instance',
            name='location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='clouds.Cloud'),
        ),
        migrations.AlterField(
            model_name='instanceblueprint',
            name='location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='clouds.Cloud'),
        ),
        migrations.AlterField(
            model_name='instancetemplate',
            name='location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='clouds.Cloud'),
        ),
        migrations.AlterField(
            model_name='volume',
            name='location',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='clouds.Cloud'),
        ),
    ]
