# Generated by Django 2.1.7 on 2019-04-03 20:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0005_auto_20190402_2147'),
    ]

    operations = [
        migrations.RenameField(
            model_name='location',
            old_name='platform',
            new_name='_driver',
        ),
        migrations.AlterField(
            model_name='instancetemplate',
            name='remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120),
        ),
    ]
