# Generated by Django 2.1.7 on 2019-04-04 01:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0007_auto_20190404_0118'),
    ]

    operations = [
        migrations.AlterField(
            model_name='instanceblueprint',
            name='name',
            field=models.CharField(max_length=50),
        ),
    ]
