# Generated by Django 2.2 on 2019-05-23 05:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0051_remove_cluster_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='cluster',
            name='active',
            field=models.BooleanField(default=True, editable=False),
        ),
    ]
