# Generated by Django 2.2 on 2019-05-28 02:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0053_auto_20190528_0258'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='scale',
            name='stack',
        ),
    ]
