# Generated by Django 2.1.7 on 2019-04-04 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0009_auto_20190404_0151'),
    ]

    operations = [
        migrations.AlterField(
            model_name='volume',
            name='status',
            field=models.PositiveIntegerField(choices=[(0, 'null'), (1, 'active'), (2, 'block'), (3, 'suspend'), (4, 'shutdown'), (5, 'poweroff'), (6, 'breakdown'), (7, 'pause'), (8, 'failure'), (9, 'host_lost'), (10, 'instance_lost'), (11, 'building')], default=11, editable=False),
        ),
        migrations.AlterUniqueTogether(
            name='instanceblueprint',
            unique_together={('location', 'name')},
        ),
        migrations.AlterUniqueTogether(
            name='instancetemplate',
            unique_together={('location', 'name')},
        ),
    ]
