# Generated by Django 2.1.7 on 2019-04-10 02:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0013_auto_20190406_0952'),
    ]

    operations = [
        migrations.AddField(
            model_name='cloud',
            name='hosts',
            field=models.TextField(blank=True, max_length=5120, null=True),
        ),
    ]
