# Generated by Django 2.1.7 on 2019-04-06 21:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0004_auto_20190405_0329'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='scale',
            name='uuid',
        ),
    ]
