# Generated by Django 2.2 on 2019-04-24 21:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0043_auto_20190420_0247'),
    ]

    operations = [
        migrations.AddField(
            model_name='scale',
            name='_remedy_script_scale_out',
            field=models.TextField(blank=True, default='', max_length=5120, verbose_name='scale-out remedy script'),
        ),
        migrations.AlterField(
            model_name='scale',
            name='_remedy_script',
            field=models.TextField(blank=True, default='', max_length=5120, verbose_name='initial remedy script'),
        ),
        migrations.AlterField(
            model_name='scale',
            name='init_blueprints',
            field=models.ManyToManyField(related_name='initialized_scales', to='clouds.InstanceBlueprint', verbose_name='initial blueprints'),
        ),
        migrations.AlterField(
            model_name='scale',
            name='step_blueprints',
            field=models.ManyToManyField(blank=True, related_name='stepped_scales', to='clouds.InstanceBlueprint', verbose_name='scale-out blueprints'),
        ),
    ]
