# Generated by Django 2.1.7 on 2019-04-13 11:11

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0021_auto_20190413_0055'),
    ]

    operations = [
        migrations.AlterField(
            model_name='instanceoperation',
            name='batch_uuid',
            field=models.UUIDField(auto_created=True, default=uuid.uuid4, editable=False),
        ),
    ]
