# Generated by Django 2.1.7 on 2019-04-09 01:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0011_cluster_deleting'),
    ]

    operations = [
        migrations.AddField(
            model_name='clusteroperation',
            name='script',
            field=models.TextField(blank=True, max_length=5120, null=True),
        ),
    ]
