# Generated by Django 2.2 on 2019-06-17 02:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0010_auto_20190614_2013'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dataengine',
            name='type',
            field=models.PositiveIntegerField(choices=[(0, 'ralational'), (1, 'raw'), (2, 'freetext'), (3, 'semistructed'), (4, 'event'), (5, 'graph'), (6, 'star_catalogue')]),
        ),
        migrations.AlterField(
            model_name='dataset',
            name='type',
            field=models.PositiveIntegerField(blank=True, choices=[(0, 'ralational'), (1, 'raw'), (2, 'freetext'), (3, 'semistructed'), (4, 'event'), (5, 'graph'), (6, 'star_catalogue')], null=True),
        ),
    ]
