# Generated by Django 2.1.7 on 2019-04-10 20:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0013_remove_scale_hosts'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cluster',
            name='engines',
            field=models.ManyToManyField(blank=True, to='engines.Engine'),
        ),
    ]
