# Generated by Django 2.1.7 on 2019-04-02 02:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0003_instanceoperation_started_time'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='instanceblueprint',
            options={'verbose_name': 'blueprint'},
        ),
        migrations.AlterModelOptions(
            name='instanceoperation',
            options={'verbose_name': 'operation'},
        ),
        migrations.RemoveField(
            model_name='instance',
            name='monitoring',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='deleting',
        ),
        migrations.AddField(
            model_name='instance',
            name='built_time',
            field=models.DateTimeField(blank=True, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='mount',
            name='built_time',
            field=models.DateTimeField(blank=True, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='volume',
            name='built_time',
            field=models.DateTimeField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name='instance',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True),
        ),
        migrations.AlterField(
            model_name='instanceoperation',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True),
        ),
        migrations.AlterField(
            model_name='mount',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True),
        ),
        migrations.AlterField(
            model_name='volume',
            name='created_time',
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]
