# Generated by Django 2.2 on 2019-04-17 07:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0039_auto_20190417_0614'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='stepoperation',
            options={'verbose_name': 'operation'},
        ),
    ]
