# Generated by Django 2.1.7 on 2019-04-13 09:21

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0029_auto_20190413_0836'),
    ]

    operations = [
        migrations.AddField(
            model_name='step',
            name='deleting',
            field=models.BooleanField(default=False, editable=False),
        ),
        migrations.AlterField(
            model_name='cluster',
            name='built_time',
            field=models.DateTimeField(blank=True, default=django.utils.timezone.now, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name='step',
            name='built_time',
            field=models.DateTimeField(blank=True, default=django.utils.timezone.now, editable=False, null=True),
        ),
    ]
