# Generated by Django 2.1.7 on 2019-04-11 01:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0015_instanceoperation_tidied'),
        ('engines', '0015_auto_20190410_2220'),
    ]

    operations = [
        migrations.AddField(
            model_name='cluster',
            name='stepping_instances',
            field=models.ManyToManyField(blank=True, editable=False, related_name='stepping_clusters', to='clouds.Instance'),
        ),
    ]
