# Generated by Django 2.2 on 2019-04-17 07:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clouds', '0030_auto_20190417_0157'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='hosts',
            field=models.TextField(default='###group {}###\n', editable=False, max_length=5120),
        ),
    ]
