# Generated by Django 2.1.7 on 2019-04-06 22:11

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0008_auto_20190406_2210'),
    ]

    operations = [
        migrations.AddField(
            model_name='cluster',
            name='scale',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.PROTECT, to='engines.Scale'),
            preserve_default=False,
        ),
    ]
