# Generated by Django 2.1.7 on 2019-04-06 22:45

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('engines', '0009_cluster_scale'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cluster',
            name='instances',
            field=models.ManyToManyField(blank=True, editable=False, to='clouds.Instance'),
        ),
        migrations.AlterField(
            model_name='cluster',
            name='owner',
            field=models.ForeignKey(editable=False, on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='cluster',
            name='remark',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
